@@ -1,6 +1,4 @@
-import platform
 import string
-import os
 import time
 import re
 import random
@@ -151,6 +149,19 @@ def random_str(length=10, chars=string.ascii_lowercase):
     return ''.join(random.sample(chars, length))
 
 
+def get_except_dic(d: dict, *arg):
+    """
+    将一个字典去除自定义的key值并返回字典
+    :param d: 初始字典
+    :param arg: 需要去除的key
+    :return: 去除指定key后的字典（原字典中没有指定的key也不会报错）
+    """
+    c = set(d) - set(arg)
+    for key in c:
+        del d[key]
+    return d
+
+
 def get_middle_text(text, prefix, suffix, index=0):
     """
     获取中间文本的简单实现
