@@ -1,8 +1,11 @@
 import base64
 import hashlib
+import logging
 import binascii
 from Crypto.Cipher import AES
 
+logger = logging.getLogger(__name__)
+
 
 def md5(s: str, salt='', encoding='utf-8') -> str:
     return hashlib.md5((s + salt).encode(encoding=encoding)).hexdigest()
@@ -27,10 +30,10 @@ class CryptoModel:
     AES加密类
     """
 
-    def __init__(self, key, iv, model=AES.MODE_CBC):
+    def __init__(self, key, iv, mode=AES.MODE_CBC):
         self.key = md5(key).encode()
         self.iv = md5(iv).encode()[8:24]
-        self.model = model
+        self.mode = mode
 
     @staticmethod
     def padding(text):
@@ -38,10 +41,20 @@ class CryptoModel:
         return text.encode('utf-8') + padding_0a
 
     def aes_encode(self, text):
-        obj = AES.new(self.key, self.model, self.iv)
+        obj = AES.new(self.key, self.mode, self.iv)
         data = self.padding(text)
         return obj.encrypt(data)
 
     def aes_decode(self, data):
-        obj = AES.new(self.key, self.model, self.iv)
+        obj = AES.new(self.key, self.mode, self.iv)
         return obj.decrypt(data)
+
+    def encrypt(self, data):
+        ' 加密函数 '
+        cryptor = AES.new(self.key, self.mode, self.iv)
+        return binascii.b2a_hex(cryptor.encrypt(data)).decode()
+
+    def decrypt(self, data):
+        ' 解密函数 '
+        cryptor = AES.new(self.key, self.mode, self.iv)
+        return cryptor.decrypt(binascii.a2b_hex(data)).decode()
