@@ -3,18 +3,35 @@ import yaml
 import shutil
 import gzip
 import ruamel.yaml
+import zipfile
+import uuid
+import logging
+
+logger = logging.getLogger(__name__)
 
 
-def read_file(file, encoding='utf-8'):
+def read_file(file, mode='r', encoding='utf-8'):
     """
     :param file: 文件名
     :param encoding: 编码，默认utf-8
+    :param mode: open方式，默认r
     :return:
     """
-    with open(file, 'r', encoding=encoding) as f:
+    with open(file, mode, encoding=encoding) as f:
         return f.read()
 
 
+def read_binary_file(file, mode='r'):
+    """
+    :param file: 文件名
+    :param mode: open方式，默认r
+    :return:
+    """
+    with open(file, mode) as f:
+        return f.read()
+
+
+
 def readline_file(file, encoding='utf-8'):
     """
     :param file: 文件名
@@ -22,7 +39,7 @@ def readline_file(file, encoding='utf-8'):
     :return:
     """
     with open(file, 'r', encoding=encoding) as f:
-        return f.read()
+        return f.readline()
 
 
 def read_yaml(config_path, config_name=''):
@@ -93,3 +110,27 @@ def unpack_file(src_file, dst_path):
     finally:
         os.remove(src_file)
         print("正在删除gz压缩文件")
+
+
+def deflated_zip(target, filename, file_url):
+    f = zipfile.ZipFile(target, 'w', zipfile.ZIP_DEFLATED)
+    f.write(filename, file_url)
+    f.close()
+
+
+def extract_zip(zip_path, target_path):
+    """
+    解压zip
+    解压成功：返回解压出的文件路径
+    解压失败：返回False
+    """
+    try:
+        uuid_str = uuid.uuid4().hex
+        f = zipfile.ZipFile(zip_path, 'r')
+        f.extractall(path=target_path + '/' + uuid_str)
+        # corrector(target_path)
+    except Exception as e:
+        logger.error(e, exc_info=True)
+        return False
+
+    return target_path + '/' + uuid_str
